-- init specs
iconSets = {"blizz", "modern"};
-- checks if the given sets exists
function existsSet(set)
	for i=1, table.getn(iconSets), 1 do
		debug(i)
		if(iconSets[i] == set) then
			return true;
		end
	end
	return false;
end

-- load available specs and roles in locale
function loadLocaleSpecs2()
	specRole = {};
	local x = 1
	for classID = 1, MAX_CLASSES, 1 do
		local _, classTag = GetClassInfoByID(classID);
		local numTabs = GetNumSpecializationsForClassID(classID);
		debug(numTabs .. " -- " ..	classTag);
		for i = 1, numTabs, 1 do
			local id, name, _, icon, _, role = GetSpecializationInfoForClassID(classID, i);
			-- debug(name .. ">>" .. id.." >> " .. role);
			if(specRole[name] == nil) then
				--specRole[x] = role;
				x = x + 1;
				specRole[name] = role;
			end

		end
	end

	debug("Specs loaded: " .. x);

end

function loadLocaleSpecs()
	specRole = { };
	for classID=1, MAX_CLASSES do
		local numTabs = GetNumSpecializationsForClassID(classID);
		for i=1, numTabs do
			local _, name, _, _, _, role = GetSpecializationInfoForClassID(classID, i);
			specRole[name] = role;
		end
	end
end


-- returns the specific role name for the spec
-- returns [TANK, HEALER, DAMAGER]
function getRoleForLocaleSpec(spec)
	local role = specRole[spec];
	if(role == nil) then
		return 0;
	end
	return role;
end

-- Returns the string for the icon for the given role
function getIconForRole(role)
	local baseDir = "Interface\\AddOns\\PvPRoles\\textures\\";
	local fileType = ".blp";
	local iconSet = tonumber(PVPRole_SV.iconSet);

	-- secured up not to allow style not provided
	if(iconSet > 0 and iconSet <= table.getn(iconSets)) then
		baseDir = baseDir .. iconSets[iconSet] .. "\\";
	end

	debug("BaseDir for icon is currently " .. baseDir);

	if(role == "TANK" or role == 1) then
		return baseDir .. "Tank" .. fileType;
	end

	if(role == "HEALER" or role == 2) then
		return baseDir .. "Heal" .. fileType;
	end

	if(role == "DAMAGER" or role == 3) then
		return baseDir .. "Damage" .. fileType;
	end
end

-- just testing
function test( )
	print(getRoleForLocaleSpec("Schutz"));
end

-- sets the current role
function setCurrentRole(role)
	currentRole = role;
	debug("Set current role to " .. role);
end

-- sets the icon set
-- allowed values [1,2] or ["blizz", "modern"]
function setIconSet(newStyle)
	if(newStyle == "blizz" or newStyle == 1) then
		PVPRole_SV.iconSet = 1;
	elseif(newStyle == "modern" or newStyle == 2) then
		PVPRole_SV.iconSet = 2;
	end

	debug("Set style to " .. PVPRole_SV.iconSet);
end

-- resets the saved vars
function resetVars()
	PVPRole_SV = {
		left = -10,	-- to TargetFrame
		top = 10,	-- to Top of TargetFrame
		iconSet = 2,-- iconSet for images
		debug = 0,   -- if set to 1, debug messages will happen
		printSpecs = 0 -- if set to 1, print spec of your target in chat
	};
end

-- prints texts if debug is activated
function debug(text)
	if(PVPRole_SV.debug == 1) then
		print("[PVPRoles - DEBUG] " .. text);
	end
end

-- prints message in the chat with prefix
function sendMsg(message)
	print("[PvPRoles] " .. message);
end

function setDebug(debugValue)
	PVPRole_SV.debug = debugValue;
end

function splitSpace(string)
	local returnArray = {};
	local counter = 1;
	for i in string.gmatch(string, "%S+") do
		returnArray[counter] = i;
		counter = counter + 1;
	end
	return returnArray;
end